@@ -1,11 +1,11 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="2.0" language="da_DK" sourcelanguage="">
+<!DOCTYPE TS><TS version="2.0" language="da_DK" sourcelanguage="en">
 <context>
     <name>LogPassDialog</name>
     <message>
         <location filename="retext.py" line="142"/>
         <source>Enter your Google account data</source>
-        <translation>Indtast oplysninger for din Google-konto</translation>
+        <translation>Indtast oplysninger til din Google-konto</translation>
     </message>
     <message>
         <location filename="retext.py" line="151"/>
@@ -20,11 +20,6 @@
 </context>
 <context>
     <name>ReTextWindow</name>
-    <message>
-        <location filename="retext.py" line="1111"/>
-        <source>New document</source>
-        <translation>Nyt dokument</translation>
-    </message>
     <message>
         <location filename="retext.py" line="212"/>
         <source>File toolbar</source>
@@ -33,7 +28,12 @@
     <message>
         <location filename="retext.py" line="214"/>
         <source>Edit toolbar</source>
-        <translation>Rediger værktøjslinie</translation>
+        <translation>Redigering-værktøjslinie</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="216"/>
+        <source>Search toolbar</source>
+        <translation>Søge-værktøjslinie</translation>
     </message>
     <message>
         <location filename="retext.py" line="218"/>
@@ -43,7 +43,7 @@
     <message>
         <location filename="retext.py" line="222"/>
         <source>Open</source>
-        <translation>Åbn</translation>
+        <translation>Åben</translation>
     </message>
     <message>
         <location filename="retext.py" line="226"/>
@@ -63,18 +63,43 @@
     <message>
         <location filename="retext.py" line="238"/>
         <source>Print preview</source>
-        <translation>Vis udskrift</translation>
+        <translation>Udskriftsvisning</translation>
     </message>
     <message>
         <location filename="retext.py" line="240"/>
         <source>View HTML code</source>
         <translation>Vis HTML-kode</translation>
     </message>
+    <message>
+        <location filename="retext.py" line="242"/>
+        <source>Change default font</source>
+        <translation>Skift standardskrifttype</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="244"/>
+        <source>Find text</source>
+        <translation>Find tekst</translation>
+    </message>
     <message>
         <location filename="retext.py" line="249"/>
         <source>Preview</source>
         <translation>Forhåndsvisning</translation>
     </message>
+    <message>
+        <location filename="retext.py" line="261"/>
+        <source>Live preview</source>
+        <translation>Live-forhåndsvisning</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="265"/>
+        <source>Fullscreen mode</source>
+        <translation>Fuldskærmsvisning</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="277"/>
+        <source>Other formats</source>
+        <translation>Andre formater</translation>
+    </message>
     <message>
         <location filename="retext.py" line="283"/>
         <source>Quit</source>
@@ -88,7 +113,7 @@
     <message>
         <location filename="retext.py" line="289"/>
         <source>Redo</source>
-        <translation>Gentag</translation>
+        <translation>Gendan</translation>
     </message>
     <message>
         <location filename="retext.py" line="293"/>
@@ -105,18 +130,48 @@
         <source>Paste</source>
         <translation>Indsæt</translation>
     </message>
+    <message>
+        <location filename="retext.py" line="315"/>
+        <source>Enable</source>
+        <translation>Aktiver</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="317"/>
+        <source>Set locale</source>
+        <translation>Sæt sprogindstillinger</translation>
+    </message>
     <message>
         <location filename="retext.py" line="328"/>
         <source>Plain text</source>
-        <translation>Indsæt tekst</translation>
+        <translation>Ren tekst</translation>
     </message>
     <message>
-        <location filename="retext.py" line="760"/>
-        <source>Open recent</source>
-        <translation>Åbn nylige</translation>
+        <location filename="retext.py" line="334"/>
+        <source>Generate webpages</source>
+        <translation>Generer websider</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1123"/>
+        <location filename="retext.py" line="336"/>
+        <source>Show</source>
+        <translation>Vis</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="338"/>
+        <source>Next</source>
+        <translation>Næste</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="340"/>
+        <source>Previous</source>
+        <translation>Foregående</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="344"/>
+        <source>Get help online</source>
+        <translation>Find hjælp online</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="1133"/>
         <source>About %1</source>
         <translation>Om %1</translation>
     </message>
@@ -155,26 +210,126 @@
         <source>Help</source>
         <translation>Hjælp</translation>
     </message>
+    <message>
+        <location filename="retext.py" line="760"/>
+        <source>Open recent</source>
+        <translation>Åben seneste</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="400"/>
+        <source>Directory</source>
+        <translation>Mappe</translation>
+    </message>
     <message>
         <location filename="retext.py" line="408"/>
         <source>Export</source>
         <translation>Eksport</translation>
     </message>
+    <message>
+        <location filename="retext.py" line="429"/>
+        <source>Spell check</source>
+        <translation>Stavekontrol</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="437"/>
+        <source>Default editing mode</source>
+        <translation>Standardredigering</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="472"/>
+        <source>Search</source>
+        <translation>Søg</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="476"/>
+        <source>Case sensitively</source>
+        <translation>Skelnen mellem store og små bogstaver</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="1121"/>
+        <source>New document</source>
+        <translation>Nyt dokument</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="493"/>
+        <source>You have neither Markdown nor Docutils modules installed!</source>
+        <translation>Du har hverken Markdown eller Docutils installeret!</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="493"/>
+        <source>Only HTML formatting will be available.</source>
+        <translation>Der vil kun være HTML-formattering til rådighed.</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="642"/>
+        <source>Enter locale name (example: en_US)</source>
+        <translation>Indtast sprogindstilling (eksempel:en_US)</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="731"/>
+        <source>Please, save the file somewhere.</source>
+        <translation>Gem venligst filen et sted.</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="718"/>
+        <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
+        <translation>Sider gemt i &lt;code&gt;html&lt;/code&gt;-mappe.</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="720"/>
+        <source>Show directory</source>
+        <translation>Vis mappe</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="725"/>
+        <source>Webpages generator is not installed!</source>
+        <translation>Hjemmesidegenerator ikke installeret!</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="765"/>
+        <source>Select one or several files to open</source>
+        <translation>Vælg en eller flere filer, der skal åbnes</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="765"/>
+        <source>Supported files</source>
+        <translation>Understøttede filer</translation>
+    </message>
     <message>
         <location filename="retext.py" line="765"/>
         <source>All files (*)</source>
         <translation>Alle filer (*)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="908"/>
-        <source>HTML files (*.html *.htm)</source>
-        <translation>HTML-filre (*.html *.htm)</translation>
+        <location filename="retext.py" line="819"/>
+        <source>Plain text (*.txt)</source>
+        <translation>Ren tekst (*.txt)</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="822"/>
+        <source>ReStructuredText files</source>
+        <translation>ReStrcturedText-filer</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="825"/>
+        <source>HTML files</source>
+        <translation>HTML-filer</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="828"/>
+        <source>Markdown files</source>
+        <translation>Markdown-filer</translation>
     </message>
     <message>
         <location filename="retext.py" line="908"/>
         <source>Save file</source>
         <translation>Gem fil</translation>
     </message>
+    <message>
+        <location filename="retext.py" line="844"/>
+        <source>Cannot save to file because it is read-only!</source>
+        <translation>Kan ikke gemme filen, fordi den er skrivebeskyttet!</translation>
+    </message>
     <message>
         <location filename="retext.py" line="899"/>
         <source>Export document to ODT</source>
@@ -185,6 +340,11 @@
         <source>OpenDocument text files (*.odt)</source>
         <translation>OpenDocument-tekstfiler (*.odt)</translation>
     </message>
+    <message>
+        <location filename="retext.py" line="908"/>
+        <source>HTML files (*.html *.htm)</source>
+        <translation>HTML-filer (*.html *.htm)</translation>
+    </message>
     <message>
         <location filename="retext.py" line="924"/>
         <source>Export document to PDF</source>
@@ -201,76 +361,14 @@
         <translation>Udskriv dokument</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1021"/>
-        <source>Incorrect user name or password!</source>
-        <translation>Fejl i brugernavn eller adgangskode!</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="1085"/>
-        <source>The document has been modified.
-Do you want to save your changes?</source>
-        <translation>Dokumentet er blevet ændret.
-Ønsker du at gemme dine ændringer?</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="1114"/>
-        <source>HTML code</source>
-        <translation>HTML-kode</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="242"/>
-        <source>Change default font</source>
-        <translation>Skift standardskrifttype</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="261"/>
-        <source>Live preview</source>
-        <translation>Live-forhåndsvisning</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="334"/>
-        <source>Generate webpages</source>
-        <translation>Generer hjemmesider</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="336"/>
-        <source>Show</source>
-        <translation>Vis</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="400"/>
-        <source>Directory</source>
-        <translation>Mappe</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="731"/>
-        <source>Please, save the file somewhere.</source>
-        <translation>Gem venligst filen.</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="718"/>
-        <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
-        <translation>Hjemmesider gemt i &lt;code&gt;html&lt;/code&gt;-mappe.</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="765"/>
-        <source>Supported files</source>
-        <translation>Understøttede filtyper</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="819"/>
-        <source>Plain text (*.txt)</source>
-        <translation>Ren tekst (*.txt)</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="277"/>
-        <source>Other formats</source>
-        <translation>Andre formater</translation>
+        <location filename="retext.py" line="963"/>
+        <source>Export document</source>
+        <translation>Eksporter dokument</translation>
     </message>
     <message>
         <location filename="retext.py" line="958"/>
         <source>This function is not available in Plain text mode!</source>
-        <translation>Denne funktion er ikke til rådighed i tekstvisning!</translation>
+        <translation>Denne funktion er ikke til rådighed, når man arbejder med ren tekst!</translation>
     </message>
     <message>
         <location filename="retext.py" line="961"/>
@@ -278,154 +376,56 @@ Do you want to save your changes?</source>
         <translation>Vælg type</translation>
     </message>
     <message>
-        <location filename="retext.py" line="963"/>
-        <source>Export document</source>
-        <translation>Eksporter dokument</translation>
+        <location filename="retext.py" line="1030"/>
+        <source>Incorrect user name or password!</source>
+        <translation>Fejl i brugernavn eller adgangskode!</translation>
     </message>
     <message>
-        <location filename="retext.py" line="493"/>
-        <source>Only HTML formatting will be available.</source>
-        <translation>Der vil kun være HTML-formattering til rådighed.</translation>
+        <location filename="retext.py" line="1033"/>
+        <source>Authentification failed, please check your internet connection!</source>
+        <translation>Login slået fejl - efterse din internetforbindelse!</translation>
     </message>
     <message>
-        <location filename="retext.py" line="315"/>
-        <source>Enable</source>
-        <translation>Aktiver</translation>
+        <location filename="retext.py" line="1095"/>
+        <source>The document has been modified.
+Do you want to save your changes?</source>
+        <translation>Dokumentet er blevet ændret.
+Ønsker du at gemme dine ændringer?</translation>
     </message>
     <message>
-        <location filename="retext.py" line="317"/>
-        <source>Set locale</source>
-        <translation>Sæt landeindstilling</translation>
+        <location filename="retext.py" line="1124"/>
+        <source>HTML code</source>
+        <translation>HTML-kode</translation>
     </message>
     <message>
-        <location filename="retext.py" line="429"/>
-        <source>Spell check</source>
-        <translation>Stavekontrol</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="642"/>
-        <source>Enter locale name (example: en_US)</source>
-        <translation>Indtast landekode (eksempel: da_DK)</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="265"/>
-        <source>Fullscreen mode</source>
-        <translation>Fuldskærmsvisning</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="216"/>
-        <source>Search toolbar</source>
-        <translation>Søgeværktøjslinie</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="244"/>
-        <source>Find text</source>
-        <translation>Find tekst</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="338"/>
-        <source>Next</source>
-        <translation>Næste</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="340"/>
-        <source>Previous</source>
-        <translation>Foregående</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="437"/>
-        <source>Default editing mode</source>
-        <translation>Standardredigering</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="472"/>
-        <source>Search</source>
-        <translation>Søg</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="476"/>
-        <source>Case sensitively</source>
-        <translation>Forskel på små/store bogstaver</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="493"/>
-        <source>You have neither Markdown nor Docutils modules installed!</source>
-        <translation>Du har hverken Markdown- eller Docutils-moduler installeret!</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="825"/>
-        <source>HTML files</source>
-        <translation>HTML-filer</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="1123"/>
-        <source>Author: Dmitry Shachnev, 2011</source>
-        <translation>Udvikler: Dmitry Shachnev, 2011</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="1123"/>
-        <source>Website</source>
-        <translation>Hjemmeside</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="1123"/>
-        <source>Markdown syntax</source>
-        <translation>Markdown-syntaks</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="1123"/>
-        <source>ReST syntax</source>
-        <translation>ReST-syntaks</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="822"/>
-        <source>ReStructuredText files</source>
-        <translation>ReStructuredText-filer</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="828"/>
-        <source>Markdown files</source>
-        <translation>Markdown-filer</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="1123"/>
+        <location filename="retext.py" line="1133"/>
         <source>Simple but powerful editor for Markdown and ReStructuredText</source>
         <translation>Enkel men stærk editor til Markdown og ReStructuredText</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1182"/>
+        <location filename="retext.py" line="1133"/>
+        <source>Author: Dmitry Shachnev, 2011</source>
+        <translation>Forfatter: Dmitry Shachnev, 2011</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="1133"/>
+        <source>Website</source>
+        <translation>Hjemmeside</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="1133"/>
+        <source>Markdown syntax</source>
+        <translation>Markdown-syntaks</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="1133"/>
+        <source>ReST syntax</source>
+        <translation>ReST-syntaks</translation>
+    </message>
+    <message>
+        <location filename="retext.py" line="1192"/>
         <source>Could not parse file contents, check if you have the necessary module installed!</source>
-        <translation>Kunne ikke tolke filens indhold. Undersøg, om du har det påkrævede modul installeret!</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="765"/>
-        <source>Select one or several files to open</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="344"/>
-        <source>Get help online</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="720"/>
-        <source>Show directory</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="725"/>
-        <source>Webpages generator is not installed!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="844"/>
-        <source>Cannot save to file because it is read-only!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="1023"/>
-        <source>Authentification failed, please check your internet connection!</source>
-        <translation type="unfinished"></translation>
+        <translation>Kunne ikke indlæse filens indhold, efterse, at du har de rette moduler installeret!</translation>
     </message>
 </context>
 </TS>
